pub trait TypeWitnessTypeArg {
type Arg: ?Sized;
}Expand description
Gets the type argument that this type witness witnesses.
example shared with MakeTypeWitness
A type witness is an enum whose variants only have TypeEq fields.
Each variant requires the enum’s type parameter to be a specific type.
This trait should be implemented generically, as generic as the type definition of the implementor, doing so will help type inference.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".